// src/devcenter-scripts-v1-script-properties-embedded-scripts.universal.ts
import { transformError as sdkTransformError } from "@wix/sdk-runtime/transform-error";
import {
  renameKeysFromSDKRequestToRESTRequest,
  renameKeysFromRESTResponseToSDKResponse
} from "@wix/sdk-runtime/rename-all-nested-keys";

// src/devcenter-scripts-v1-script-properties-embedded-scripts.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveComWixpressMarketAimApiEmbeddedScriptsServiceUrl(opts) {
  const domainToMappings = {
    "api._api_base_domain_": [
      {
        srcPath: "/app-instance-manager-webapp",
        destPath: ""
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/apps",
        destPath: ""
      }
    ],
    "wixapis.com": [
      {
        srcPath: "/apps",
        destPath: ""
      }
    ],
    "dev._base_domain_": [
      {
        srcPath: "/_api/app-instance-manager",
        destPath: ""
      },
      {
        srcPath: "/api/v1/instance",
        destPath: "/v1/instance"
      },
      {
        srcPath: "/api/v1/scripts",
        destPath: "/v1/scripts"
      }
    ],
    "manage._base_domain_": [
      {
        srcPath: "/_api/app-instance-manager",
        destPath: ""
      }
    ],
    "www._base_domain_": [
      {
        srcPath: "/_api/app-instance-manager",
        destPath: ""
      }
    ],
    "editor._base_domain_": [
      {
        srcPath: "/_api/app-instance-manager",
        destPath: ""
      }
    ],
    "blocks._base_domain_": [
      {
        srcPath: "/_api/app-instance-manager",
        destPath: ""
      }
    ],
    "create.editorx": [
      {
        srcPath: "/_api/app-instance-manager",
        destPath: ""
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_app-management_embedded-scripts";
function embedScript(payload) {
  function __embedScript({ host }) {
    const metadata = {
      entityFqdn: "wix.devcenter.scripts.v1.script_properties",
      method: "POST",
      methodFqn: "com.wixpress.market.aim.api.EmbeddedScriptsService.EmbedScript",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressMarketAimApiEmbeddedScriptsServiceUrl({
        protoPath: "/v1/scripts",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __embedScript;
}
function getEmbeddedScript(payload) {
  function __getEmbeddedScript({ host }) {
    const metadata = {
      entityFqdn: "wix.devcenter.scripts.v1.script_properties",
      method: "GET",
      methodFqn: "com.wixpress.market.aim.api.EmbeddedScriptsService.GetEmbeddedScript",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressMarketAimApiEmbeddedScriptsServiceUrl({
        protoPath: "/v1/scripts",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __getEmbeddedScript;
}

// src/devcenter-scripts-v1-script-properties-embedded-scripts.universal.ts
async function embedScript2(properties, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    properties,
    componentId: options?.componentId
  });
  const reqOpts = embedScript(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          properties: "$[0]",
          componentId: "$[1].componentId"
        },
        singleArgumentUnchanged: false
      },
      ["properties", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function getEmbeddedScript2(options) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    componentId: options?.componentId
  });
  const reqOpts = getEmbeddedScript(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data)?.properties;
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { componentId: "$[0].componentId" },
        singleArgumentUnchanged: false
      },
      ["options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}

// src/devcenter-scripts-v1-script-properties-embedded-scripts.public.ts
function embedScript3(httpClient) {
  return (properties, options) => embedScript2(
    properties,
    options,
    // @ts-ignore
    { httpClient }
  );
}
function getEmbeddedScript3(httpClient) {
  return (options) => getEmbeddedScript2(
    options,
    // @ts-ignore
    { httpClient }
  );
}

// src/devcenter-scripts-v1-script-properties-embedded-scripts.context.ts
import { createRESTModule } from "@wix/sdk-runtime/rest-modules";
var embedScript4 = /* @__PURE__ */ createRESTModule(embedScript3);
var getEmbeddedScript4 = /* @__PURE__ */ createRESTModule(getEmbeddedScript3);
export {
  embedScript4 as embedScript,
  getEmbeddedScript4 as getEmbeddedScript
};
//# sourceMappingURL=index.mjs.map